@@ -37,6 +37,23 @@ DW_LANG_ObjC_plus_plus = 0x0011
 DW_LANG_UPC = 0x0012
 DW_LANG_D = 0x0013
 DW_LANG_Python = 0x0014
+DW_LANG_OpenCL = 0x0015
+DW_LANG_Go = 0x0016
+DW_LANG_Modula3 = 0x0017
+DW_LANG_Haskell = 0x0018
+DW_LANG_C_plus_plus_03 = 0x0019
+DW_LANG_C_plus_plus_11 = 0x001a
+DW_LANG_OCaml = 0x001b
+DW_LANG_Rust = 0x001c
+DW_LANG_C11 = 0x001d
+DW_LANG_Swift = 0x001e
+DW_LANG_Julia = 0x001f
+DW_LANG_Dylan = 0x0020
+DW_LANG_C_plus_plus_14 = 0x0021
+DW_LANG_Fortran03 = 0x0022
+DW_LANG_Fortran08 = 0x0023
+DW_LANG_RenderScript = 0x0024
+DW_LANG_BLISS = 0x0025
 DW_LANG_Mips_Assembler = 0x8001
 DW_LANG_Upc = 0x8765
 DW_LANG_HP_Bliss = 0x8003
@@ -44,6 +61,8 @@ DW_LANG_HP_Basic91 = 0x8004
 DW_LANG_HP_Pascal91 = 0x8005
 DW_LANG_HP_IMacro = 0x8006
 DW_LANG_HP_Assembler = 0x8007
+DW_LANG_GOOGLE_RenderScript = 0x8e57
+DW_LANG_BORLAND_Delphi = 0xb000
 
 
 # Encoding
@@ -65,6 +84,8 @@ DW_ATE_signed_fixed = 0xd
 DW_ATE_unsigned_fixed = 0xe
 DW_ATE_decimal_float = 0xf
 DW_ATE_UTF = 0x10
+DW_ATE_UCS = 0x11
+DW_ATE_ASCII = 0x12
 DW_ATE_lo_user = 0x80
 DW_ATE_hi_user = 0xff
 DW_ATE_HP_float80 = 0x80
