@@ -9,12 +9,13 @@
 #-------------------------------------------------------------------------------
 import os, sys
 import logging
-from utils import setup_syspath; setup_syspath()
 from utils import run_exe, is_in_rootdir, dump_output_to_temp_files
 
+# Make it possible to run this file from the root dir of pyelftools without
+# installing pyelftools; useful for Travis testing, etc.
+sys.path[0:0] = ['.']
 
 # Create a global logger object
-#
 testlog = logging.getLogger('run_examples_test')
 testlog.setLevel(logging.DEBUG)
 testlog.addHandler(logging.StreamHandler(sys.stdout))
@@ -86,4 +87,3 @@ def main():
 
 if __name__ == '__main__':
     sys.exit(main())
-
