@@ -4,15 +4,12 @@
 # Eli Bendersky (eliben@gmail.com), Santhosh Kumar Mani (santhoshmani@gmail.com)
 # This code is in the public domain
 #-------------------------------------------------------------------------------
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
 import os
+import unittest
 
-from utils import setup_syspath; setup_syspath()
 from elftools.elf.elffile import ELFFile
 
+
 class TestRangeLists(unittest.TestCase):
     # Test the absence of .debug_ranges section
     def test_range_list_absence(self):
@@ -30,5 +27,6 @@ class TestRangeLists(unittest.TestCase):
             self.assertTrue(elffile.has_dwarf_info())
             self.assertIsNotNone(elffile.get_dwarf_info().range_lists())
 
+
 if __name__ == '__main__':
     unittest.main()
